﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

/*Espacios de nombres para el trabajo
con Aplicaciones Web*/
using Microsoft.SharePoint.Administration;
using System.Security;

namespace SharePoint_AplWeb
{
    class Program
    {
        static void Main(string[] args)
        {
            //******************************
            //Trabajo con Aplicaciones Web.*
            //******************************
            //ListarAplicacionesWeb();
            //GestionarAplicacionesWeb("C");
            //GestionarAplicacionesWeb("U");
            GestionarAplicacionesWeb("D");
        }

        /// <summary>
        /// Lista las aplicaciones web de una granja
        /// </summary>
        public static void ListarAplicacionesWeb()
        {
            //Colección de apliaciones web en el contexto actual

            SPWebApplicationCollection spwaColleccionWebApp =
                   SPWebService.ContentService.WebApplications;

            //Si hay aplicaciones web en la colección    
            if (spwaColleccionWebApp != null)
            {
                //Aplicaciones Web contenidas en la colección
                foreach (var spwWebApp in spwaColleccionWebApp)
                {
                    //Datos de la aplicación web
                    Console.WriteLine("Aplicación Web: {0}",
                        spwWebApp.Name);
                    Console.WriteLine(" + Grupo de Aplicaciones: {0}",
                        spwWebApp.ApplicationPool.Name +
                        " (Estado: " + spwWebApp.ApplicationPool.Status + ")");
                    Console.WriteLine(" + Zona Horaria: {0}",
                        spwWebApp.DefaultTimeZone);
                    Console.WriteLine(" + Número máximo de alertas: {0}",
                        spwWebApp.AlertsMaximum.ToString());
                    Console.WriteLine(" + Tamaño máximo de subida (MB): {0}",
                        spwWebApp.MaximumFileSize.ToString());
                    Console.WriteLine(" + Quota por defecto: {0}",
                        spwWebApp.DefaultQuotaTemplate);

                    //Bases de datos asociadas a cada aplicación web
                    SPContentDatabaseCollection spcdbColeccionBDs =
                        spwWebApp.ContentDatabases;
                    Console.WriteLine(" + Nº de BD's asociadas {0}",
                        spcdbColeccionBDs.Count);
                    foreach (var spcdb in spcdbColeccionBDs)
                    {
                        Console.WriteLine("    - Servidor de BD: {0}",
                            spcdb.Server);
                        Console.WriteLine("    - Instancia de BD: {0}",
                            spcdb.ServiceInstance);
                        Console.WriteLine("    - Nombre de la BD: {0}",
                            spcdb.Name);
                        Console.WriteLine("    - Cadena de conexión: {0}",
                            spcdb.DatabaseConnectionString);
                        Console.WriteLine("    - ¿Es sólo lectura?: {0}",
                            spcdb.IsReadOnly);
                    }
                }
            }
            Console.ReadLine();
        }
        
        /// <summary>
        /// Permite crear, actualizar y/o borrar una Aplicación Web
        /// </summary>
        /// <param name="sOpcion">Representa la operación a realizar: C (Crear), U (Actualizar) y D (Borrar)</param>
        public static void GestionarAplicacionesWeb(string sOpcion)
        {
            switch (sOpcion)
            {
                case "C":
                    try
                    {
                        SPWebApplicationBuilder spwaBuilder =
                            new SPWebApplicationBuilder(SPFarm.Local);
                        SPWebApplication spwWebApp;
                        spwaBuilder.Port = 90;
                        //Grupo de aplicaciones y cuenta de usuario
                        spwaBuilder.ApplicationPoolId =
                            "SharePoint - 90";
                        spwaBuilder.ApplicationPoolUsername =
                            "Administrador";
                        SecureString ssPass = new SecureString();
                        string sPass = "Numero1";
                        char[] cPass = sPass.ToCharArray();
                        foreach (char c in cPass)
                            ssPass.AppendChar(c);
                        spwaBuilder.ApplicationPoolPassword = ssPass;
                        //BD de contenidos
                        spwaBuilder.CreateNewDatabase = true;
                        spwaBuilder.DatabaseName =
                            "WSS_Content_90";
                        //Servidor de BD
                        spwaBuilder.DatabaseServer =
                            spwaBuilder.DefaultZoneUri.Host;
                        //Autenticación NTLM
                        spwaBuilder.UseNTLMExclusively = true;
                        //Creamos la aplicación web                        
                        spwWebApp = spwaBuilder.Create();
                        //Provisionamos la aplicación web en la granja
                        spwWebApp.Provision();
                        Console.WriteLine(
                            "Aplicación web creada con éxito");
                    }
                    catch (Exception ex)
                    {
                        Console.WriteLine(
                            "Error en la creación de la Aplicación web: {0}",
                            ex.Message);
                    }
                    break;
                case "U":
                    try
                    {
                        SPWebApplication spwWebApp =
                            SPWebApplication.Lookup(
                            new Uri("http://sagitario:90"));
                        spwWebApp.AlertsMaximum = 1000;
                        spwWebApp.MaximumFileSize = 70;
                        spwWebApp.Update();
                        Console.WriteLine(
                            "Aplicación web actualizada con éxito");
                    }
                    catch (Exception ex)
                    {
                        Console.WriteLine(
                            "Error en la actualización de la Aplicación web: {0}",
                            ex.Message);
                    }
                    break;
                case "D":
                    try
                    {
                        SPWebApplication spwWebApp =
                            SPWebApplication.Lookup(
                            new Uri("http://sagitario:90"));
                        spwWebApp.Delete();
                        Console.WriteLine(
                            "Aplicación web borrada con éxito");
                    }
                    catch (Exception ex)
                    {
                        Console.WriteLine(
                            "Error en el borrado de la Aplicación web: {0}",
                            ex.Message);
                    }
                    break;
                default:
                    break;
            }
            Console.ReadLine();

        }
    }
}
