﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

//Referencias necesarias
using System.Net;
using MOCliente_REST.IntranetServiceReference;

namespace MOCliente_REST
{
    public partial class frmREST : Form
    {
        public frmREST()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Lista los anuncios contenidos en la lista "Anuncios"
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnListar_Click(object sender, EventArgs e)
        {
            try
            {
                IntranetDataContext ctx =
                    new IntranetDataContext(
                        new Uri(
                            "http://sagitario/_vti_bin/ListData.svc",
                            UriKind.Absolute));
                ctx.Credentials =
                    CredentialCache.DefaultCredentials;
                grdDatos.DataSource =
                    ctx.Anuncios.ToList();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "¡Error!",
                    MessageBoxButtons.OK,
                    MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Permite crear un nuevo anuncio en la lista Anuncios
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnCrear_Click(object sender, EventArgs e)
        {
            try
            {
                IntranetDataContext ctx =
                  new IntranetDataContext(
                      new Uri(
                          "http://sagitario/_vti_bin/ListData.svc",
                          UriKind.Absolute));
                ctx.Credentials =
                    CredentialCache.DefaultCredentials;

                AnunciosItem nAnucio = new AnunciosItem();
                nAnucio.Título = txtTitulo.Text;
                nAnucio.Cuerpo = txtCuerpo.Text;
                ctx.AddToAnuncios(nAnucio);
                ctx.SaveChanges();
                MessageBox.Show("El anuncio se ha creado con éxito",
                    "¡Información!",
                    MessageBoxButtons.OK,
                    MessageBoxIcon.Information);
                btnListar_Click(null, null);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "¡Error!",
                    MessageBoxButtons.OK,
                    MessageBoxIcon.Error);

            }
        }

        /// <summary>
        /// Actualiza el anuncion seleccionado
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnActualizar_Click(object sender, EventArgs e)
        {
            try
            {
                int iRowSelected =
                    grdDatos.Rows.GetFirstRow(
                    DataGridViewElementStates.Selected);
                string sTitle =
                    grdDatos.Rows[iRowSelected].Cells["Título"].Value.ToString();
                IntranetDataContext ctx =
                  new IntranetDataContext(
                      new Uri(
                          "http://sagitario/_vti_bin/ListData.svc",
                          UriKind.Absolute));
                ctx.Credentials =
                    CredentialCache.DefaultCredentials;

                AnunciosItem AnunciosItemToUpdate =
                    (from a in ctx.Anuncios
                     where a.Título == sTitle
                     select a).First();
                AnunciosItemToUpdate.Título = txtTitulo.Text;
                AnunciosItemToUpdate.Cuerpo = txtCuerpo.Text;
                ctx.UpdateObject(AnunciosItemToUpdate);
                ctx.SaveChanges();

                MessageBox.Show("El anuncio se ha actualiado con éxito",
                    "¡Información!",
                    MessageBoxButtons.OK,
                    MessageBoxIcon.Information);

                btnListar_Click(null, null);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "¡Error!",
                    MessageBoxButtons.OK,
                     MessageBoxIcon.Error);
            }
        }

        /// <summary>
        /// Elimina el anuncio seleccionado
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>

        private void btnBorrar_Click(object sender, EventArgs e)
        {
            try
            {
                int iRowSelected =
                    grdDatos.Rows.GetFirstRow(
                    DataGridViewElementStates.Selected);
                string sTitle =
                    grdDatos.Rows[iRowSelected].Cells["Título"].Value.ToString();
                IntranetDataContext ctx =
                  new IntranetDataContext(
                      new Uri(
                          "http://sagitario/_vti_bin/ListData.svc",
                          UriKind.Absolute));
                ctx.Credentials =
                    CredentialCache.DefaultCredentials;

                AnunciosItem AnunciosItemToDelete =
                    (from a in ctx.Anuncios
                     where a.Título == sTitle
                     select a).First();
                ctx.DeleteObject(AnunciosItemToDelete);
                ctx.SaveChanges();

                MessageBox.Show("El anuncio se ha borrado con éxito",
                    "¡Información!",
                    MessageBoxButtons.OK,
                    MessageBoxIcon.Information);


                btnListar_Click(null, null);
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "¡Error!",
                    MessageBoxButtons.OK,
                     MessageBoxIcon.Error);
            }
        }
    }
}
