﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

//Modelo de objetos en cliente - Implementación Silverlight
using MO_Silverlight = Microsoft.SharePoint.Client;

namespace MOCliente_Silverlight
{
    public partial class MainPage : UserControl
    {
        //Eventos y delegados para la gestión de las comunicaciones asíncronas con el servidor
        private System.Threading.SynchronizationContext thread;
        public static event MO_Silverlight.ClientRequestSucceededEventHandler crseComunicacionOK;
        public static event MO_Silverlight.ClientRequestFailedEventHandler crfeComunicacionNoOK;
        public delegate void crseComunicacionOKDelegate(
            object sender, MO_Silverlight.ClientRequestSucceededEventArgs e);
        public delegate void crfeComunicacionNoOKDelegate(
            object sender, MO_Silverlight.ClientRequestFailedEventArgs e);

        //Miembros del modelo de objetos
        MO_Silverlight.Web oWebsite = null;
        MO_Silverlight.ClientContext ctx = null;
        MO_Silverlight.ListCollection collList = null;
        IEnumerable<MO_Silverlight.List> ieListas;
      
        public MainPage()
        {
            InitializeComponent();
            crseComunicacionOKDelegate OKDelegate =
                new crseComunicacionOKDelegate(ManejarPeticionClienteOK);
            crfeComunicacionNoOKDelegate NoOKDelegate =
                new crfeComunicacionNoOKDelegate(ManejarPeticionClienteNoOK);
            crseComunicacionOK +=
                new MO_Silverlight.ClientRequestSucceededEventHandler(OKDelegate);
            crfeComunicacionNoOK +=
                new MO_Silverlight.ClientRequestFailedEventHandler(NoOKDelegate);
            thread =
                System.Threading.SynchronizationContext.Current;

            if (thread == null)
            {
                thread =
                    new System.Threading.SynchronizationContext();
            }      
        }

        /// <summary>
        /// Permite crear una nueva lista en el sitio de trabajo y mostrar información
        /// de las listas existentes.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnCreateList_Click(object sender, RoutedEventArgs e)
        {
            lblResult.Content = String.Empty;
            try
            {
                using (ctx =
                    new MO_Silverlight.ClientContext(txtSiteUrl.Text))
                {
                    //Parámetros para crear la lista
                    ctx =
                        new MO_Silverlight.ClientContext(txtSiteUrl.Text);
                    MO_Silverlight.ListCreationInformation lciCalendario =
                        new MO_Silverlight.ListCreationInformation();                    
                    lciCalendario.Title = txtListName.Text;
                    lciCalendario.Description =
                        "Calendario crado desde el MO Silverlight";
                    lciCalendario.TemplateType =
                        (int)MO_Silverlight.ListTemplateType.Events;
                    lciCalendario.QuickLaunchOption =
                        MO_Silverlight.QuickLaunchOptions.On;
                    MO_Silverlight.List llList =
                        ctx.Web.Lists.Add(lciCalendario);

                    //Parámetros para crear un elemento de lista
                    MO_Silverlight.ListItemCreationInformation liciItem =
                        new MO_Silverlight.ListItemCreationInformation();
                    MO_Silverlight.ListItem liItem =
                        llList.AddItem(liciItem);
                    liItem["Title"] = "Nuevo evento de calendario";
                    liItem["Description"] =
                        "Se ha creado un nuevo evento en el calendario";
                    liItem.Update();

                    //Definición de objetos
                    oWebsite = ctx.Web;
                    collList = oWebsite.Lists;

                    //Carga de operaciones
                    ctx.Load(oWebsite, w => w.Title);
                    ieListas = ctx.LoadQuery(collList);

                    ctx.ExecuteQueryAsync(crseComunicacionOK,
                        crfeComunicacionNoOK);
                    lblResult.Content =
                        "¡Calendario creado con éxito!";
                }

            }
            catch (Exception ex)
            {
                lblResult.Content =
                    "Se ha producido el siguiente error:" +
                    ex.Message;
            }
        }

        /// <summary>
        /// Se encarga de gestionar las peticiones al servidor que se realizan con éxito
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="args"></param>
        public void ManejarPeticionClienteOK(object sender,
            MO_Silverlight.ClientRequestSucceededEventArgs args)
        {
            thread.Post(new System.Threading.SendOrPostCallback(
                delegate(object oEstado)
                {
                    EventHandler eh = OperacionOK;
                    if (eh != null)
                    {
                        eh(this, EventArgs.Empty);

                    }
                }), null);
        }

        /// <summary>
        /// Se encarga de gestionar las peticiones al servidor que se realizan de forma fallida
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="args"></param>
        public void ManejarPeticionClienteNoOK(object sender,
            MO_Silverlight.ClientRequestFailedEventArgs args)
        {
            thread.Post(new System.Threading.SendOrPostCallback(
                delegate(object oEstado)
                {
                    EventHandler eh = OperacionNoOK;
                    if (eh != null)
                    {
                        eh(this, EventArgs.Empty);
                    }
                }), null);
        }

        /// <summary>
        /// Realiza las acciones correspondientes si la comunicación ha sido correcta
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        public void OperacionOK(object sender, EventArgs e)
        {
            lblResult.Content +=
                "Operación realizada con éxito";
            DisplayInfo();            
        }

        /// <summary>
        /// Realiza las acciones correspondientes si la comunicación ha sido incorrecta
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        public void OperacionNoOK(object sender, EventArgs e)
        {
            lblResult.Content +=
                "Error en la operación";
        }

        /// <summary>
        /// Permite mostrar la información relativa a las listas del sitio
        /// en los controles ListBox y Chart de la aplicación Silverlight
        /// </summary>
        private void DisplayInfo()
        {
            collList = oWebsite.Lists;
            lblResult.Content += " \n\t  en el sitio " + oWebsite.Title;
            List<ListaSitio> lstListas = new List<ListaSitio>();

            foreach (MO_Silverlight.List oList in ieListas)
            {
                lstDatos.Items.Add(oList.Title +
                    " - Nº Elementos: " + oList.ItemCount.ToString());
                if (oList.ItemCount > 6)
                {
                    lstListas.Add(new ListaSitio()
                    {
                        sNombreLista = oList.Title,
                        iNumeroElementos = oList.ItemCount
                    });
                }
            }
            chrListas.DataContext = lstListas;
        }      
    }

    public class ListaSitio
    {
        public string sNombreLista { get; set; }
        public int iNumeroElementos { get; set; }
    }

      
}
